==> node-marked-man_0.7.0.orig.tar.gz: marked-man-0.7.0/test/md/table.md <==
table(7) -- test data for table format
======================================

test table copy and paste form www. 


LARGE TABLE
-----------

<https://en.wikipedia.org/wiki/Comparison_of_file_systems>

File system |Creator |Year of introduction |Original operating system
------------|--------|---------------------|---------------
DECtape |DEC |1964 |PDP-6 Monitor
DASD |IBM |1964 |OS/360
Level-D |DEC |1968 |TOPS-10
George 2 |ICT (later ICL) |1968 |George 2
Version 6 Unix file system (V6FS) |Bell Labs |1972 |Version 6 Unix
RT-11 file system |DEC |1973 |RT-11
Disk Operating System (GEC DOS) |GEC |1973 |Core Operating System
CP/M file system |Digital Research (Gary Kildall) |1974 |CP/M[1][2]
ODS-1 |DEC |1975 |RSX-11
GEC DOS filing system extended |GEC |1977 |OS4000
FAT (8-bit) |Microsoft (Marc McDonald) for NCR |1977 |Microsoft Standalone Disk BASIC-80 (later Microsoft Standalone Disk BASIC-86)
DOS 3.x |Apple Computer |1978 |Apple DOS
Pascal |Apple Computer |1978 |Apple Pascal
CBM DOS |Commodore |1978 |Commodore BASIC
Version 7 Unix file system (V7FS) |Bell Labs |1979 |Version 7 Unix
ODS-2 |DEC |1979 |OpenVMS
FAT12 |Seattle Computer Products (Tim Paterson) |1980 |QDOS/86-DOS (later IBM PC DOS 1.0)
DFS |Acorn Computers Ltd |1982 |Acorn BBC Micro MOS
ADFS |Acorn Computers Ltd |1983 |Acorn Electron (later Arthur RISC OS)
FFS |Kirk McKusick |1983 |4.2BSD
ProDOS |Apple Computer |1983 |ProDOS 8
FAT16 |IBM, Microsoft |1984 |PC DOS 3.0, MS-DOS 3.0
MFS |Apple Computer |1984 |System 1
Elektronika BK tape format |NPO "Scientific centre" (now Sitronics) |1985 |Vilnius Basic, BK monitor program
HFS |Apple Computer |1985 |System 2.1
Amiga OFS[1] |Metacomco for Commodore |1985 |Amiga OS
NWFS |Novell |1985 |NetWare 286
High Sierra |Ecma International |1986 |MSCDEX for MS-DOS 3.1/3.2[3]
FAT16B |Compaq |1987 |Compaq MS-DOS 3.31
Minix V1 FS |Andrew S. Tanenbaum |1987 |MINIX 1.0
Amiga FFS |Commodore |1988 |Amiga OS 1.3
ISO 9660:1988 |Ecma International, ISO |1988 |MS-DOS, "classic" Mac OS, and AmigaOS
HPFS |IBM & Microsoft |1989 |OS/2 1.2
JFS1 |IBM |1990 |AIX[a]
VxFS |VERITAS |1991 |SVR4.0
ext |Rémy Card |1992 |Linux
AdvFS |DEC |1993[4] |Digital Unix
NTFS |Microsoft (Gary Kimura, Tom Miller) |1993 |Windows NT 3.1
LFS |Margo Seltzer |1993 |Berkeley Sprite
ext2 |Rémy Card |1993 |Linux, Hurd
Xiafs |Q. Frank Xia |1993 |Linux
UFS1 |Kirk McKusick |1994 |4.4BSD
XFS |SGI |1994 |IRIX, Linux, FreeBSD
HFS |IBM |1994 |MVS/ESA (now z/OS)
FAT16X |Microsoft |1995 |MS-DOS 7.0 / Windows 95
Joliet ("CDFS") |Microsoft |1995 |Microsoft Windows, Linux, "classic" Mac OS, and FreeBSD
UDF |ISO/ECMA/OSTA |1995 |N/A
FAT32, FAT32X |Microsoft |1996 |MS-DOS 7.10 / Windows 95 OSR2[b]
QFS |Sun Microsystems |1996 |Solaris
GPFS |IBM |1996 |AIX, Linux
Be File System |Be Inc. (D. Giampaolo, Cyril Meurillon) |1996 |BeOS
Minix V2 FS |Andrew S. Tanenbaum |1997 |MINIX 2.0
HFS Plus |Apple Computer |1998 |Mac OS 8.1
NSS |Novell |1998 |NetWare 5
PolyServe File System (PSFS) |PolyServe |1998 |Windows, Linux
ODS-5 |DEC |1998 |OpenVMS 7.2
WAFL |NetApp |1998 |Data ONTAP
ext3 |Dr. Stephen C. Tweedie |1999 |Linux
ISO 9660:1999 |Ecma International, ISO |1999 |Microsoft Windows, Linux, "classic" Mac OS, FreeBSD, and AmigaOS
Lustre |Cluster File Systems[5] |2002 |Linux
JFS |IBM |1999 |OS/2 Warp Server for e-business
GFS |Sistina (Red Hat) |2000 |Linux
ReiserFS |Namesys |2001 |Linux
zFS |IBM |2001 |z/OS (backported to OS/390)
FATX |Microsoft |2002 |Xbox
UFS2 |Kirk McKusick |2002 |FreeBSD 5.0
OCFS |Oracle Corporation |2002 |Linux
VMFS2 |VMware |2002 |VMware ESX Server 2.0
Fossil |Bell Labs |2003 |Plan 9 version 4
Google File System |Google |2003 |Linux
ZFS |Sun Microsystems |2004 |Solaris
Reiser4 |Namesys |2004 |Linux
Non-Volatile File System |Palm, Inc. |2004 |Palm OS Garnet
Minix V3 FS |Andrew S. Tanenbaum |2005 |MINIX 3
OCFS2 |Oracle Corporation |2005 |Linux
NILFS |NTT |2005 |Linux
VMFS3 |VMware |2005 |VMware ESX Server 3.0
GFS2 |Red Hat |2006 |Linux
ext4 |various |2006 |Linux
exFAT |Microsoft |2006 |Windows CE 6.0
Btrfs |Oracle Corporation |2007 |Linux
JXFS |Hyperion Entertainment |2008 |AmigaOS 4.1
HAMMER |Matthew Dillon |2008 |DragonFly BSD 2.0
LSFS |StarWind Software |2009 |Linux, FreeBSD, Windows
CASL |Nimble Storage |2010 |Linux
VMFS5 |VMware |2011 |vSphere 5.0+
ReFS |Microsoft |2012 |Windows Server 2012
F2FS |Samsung Electronics |2012 |Linux
APFS |Apple Computer |2016 |macOS


LONG TEXT
---------

http://www.troff.org/faq.html

Person|Work|Quote
-|-|-
Sherlock Holmes|The Norwood Builder| You mentioned your name as if I should recognize it, but beyond the obvious facts that you are a bachelor, a solicitor, a freemason, and an asthmatic, I know nothing whatever about you.



THING TABLE
-----------

1|2
-|-
1|2
1|2
1|2
1|2
1|2
T{1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2


REPORTING BUGS
--------------

<xxxxx@xxxx.xxxx.xxxx.xx>

==> node-marked-man_1.3.6.orig.tar.gz: marked-man-1.3.6/test/md/table.md <==
table(7) -- test data for table format
======================================

test table copy and paste form www.

LARGE TABLE
-----------

[Comparison of file systems](https://en.wikipedia.org/wiki/Comparison_of_file_systems)

File system |Creator |Year of introduction |Original operating system
------------|--------|---------------------|---------------
DECtape |DEC |1964 |PDP-6 Monitor
DASD |IBM |1964 |OS/360
Level-D |DEC |1968 |TOPS-10
George 2 |ICT (later ICL) |1968 |George 2
Version 6 Unix file system (V6FS) |Bell Labs |1972 |Version 6 Unix
RT-11 file system |DEC |1973 |RT-11
Disk Operating System (GEC DOS) |GEC |1973 |Core Operating System
CP/M file system |Digital Research (Gary Kildall) |1974 |CP/M[1]
ODS-1 |DEC |1975 |RSX-11
GEC DOS filing system extended |GEC |1977 |OS4000
FAT (8-bit) |Microsoft (Marc McDonald) for NCR |1977 |Microsoft Standalone Disk BASIC-80 (later Microsoft Standalone Disk BASIC-86)
DOS 3.x |Apple Computer |1978 |Apple DOS
Pascal |Apple Computer |1978 |Apple Pascal
CBM DOS |Commodore |1978 |Commodore BASIC
Version 7 Unix file system (V7FS) |Bell Labs |1979 |Version 7 Unix
ODS-2 |DEC |1979 |OpenVMS

LONG TEXT
---------

Person|Work|Quote
-|-|-
Sherlock Holmes|The Norwood Builder| You mentioned your name as if I should recognize it, but beyond the obvious facts that you are a bachelor, a solicitor, a freemason, and an asthmatic, I know nothing whatever about you.

THING TABLE
-----------

1|2
-|-
1|2
1|2
1|2
1|2
1|2
T{1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
1|2
